# -*- coding: utf-8 -*-
# SPDX-License-Identifier: MIT
import os

class BaseConfiguration(object):
    DEBUG = False
    SECRET_KEY = os.urandom(16)
    SQLALCHEMY_DATABASE_URI = "sqlite:///{0}".format(os.path.join(
        os.getcwd(), "module_build_service.db"))
    SQLALCHEMY_TRACK_MODIFICATIONS = True
    # Where we should run when running "manage.py run" directly.
    HOST = "0.0.0.0"
    PORT = 5000

    # URL to a path which contains GIT repositories to build from.
    RPMS_DEFAULT_REPOSITORY = "https://exampledomain/default-rpm-repositories/"

    # Define command to clone GIT repository present in RPMS_DEFAULT_REPOSITORY and a command to retrieve the sources if needed.
    # The {repo_path} will be replaced during runtime with a path to the repository.
    DISTGITS = {RPMS_DEFAULT_REPOSITORY:('git clone {repo_path}', 'true')}
    DISTGITS.update({'file://': ('git clone {repo_path}', 'true')})


class TestConfiguration(BaseConfiguration):
    LOG_LEVEL = "debug"
    SQLALCHEMY_DATABASE_URI = os.environ.get("DATABASE_URI", "sqlite:///:memory:")
    DEBUG = True
    MESSAGING = "in_memory"
    PDC_URL = "https://exampledomain/REST-API"

    # Global network-related values, in seconds
    NET_TIMEOUT = 3
    NET_RETRY_INTERVAL = 1
    # SCM network-related values, in seconds
    SCM_NET_TIMEOUT = 0.1
    SCM_NET_RETRY_INTERVAL = 0.1

    KOJI_CONFIG = "./conf/koji.conf"
    KOJI_PROFILE = "staging"
    SERVER_NAME = "localhost"

    KOJI_REPOSITORY_URL = "https://exampledomain/koji-repositories/"
    SCMURLS = ["https://exampledomain/default-module-repositories/"]

    ALLOWED_GROUPS_TO_IMPORT_MODULE = {"mbs-import-module"}

    # Greenwave configuration
    GREENWAVE_URL = "https://greenwave.example.local/api/v1.0/"
    GREENWAVE_DECISION_CONTEXT = "test_dec_context"
    GREENWAVE_SUBJECT_TYPE = "some-module"

    STREAM_SUFFIXES = {r"^el\d+\.\d+\.\d+\.z$": 0.1}

    # Ensures task.delay executes locally instead of scheduling a task to a queue.
    CELERY_TASK_ALWAYS_EAGER = True


class ProdConfiguration(BaseConfiguration):
    pass


class LocalBuildConfiguration(BaseConfiguration):
    CACHE_DIR = "~/modulebuild/cache"
    LOG_LEVEL = "debug"
    MESSAGING = "in_memory"

    ALLOW_CUSTOM_SCMURLS = True
    RESOLVER = "mbs"
    RPMS_ALLOW_REPOSITORY = True
    MODULES_ALLOW_REPOSITORY = True

    # Celery tasks will be executed locally for local builds
    CELERY_TASK_ALWAYS_EAGER = True


class OfflineLocalBuildConfiguration(LocalBuildConfiguration):
    RESOLVER = "local"


class DevConfiguration(LocalBuildConfiguration):
    DEBUG = True
